%define url_ver	%(echo %{version} | tr '.' '_')

Summary:	Open source MSX emulator
Name:		openmsx
Version:	18.0
Release:	%mkrel 2
License:        GPLv2+
Group:          Emulators
URL:            http://openmsx.sourceforge.net/
Source0:	https://github.com/openMSX/openMSX/releases/download/RELEASE_%{url_ver}/openmsx-%{version}.tar.gz
Source1:	https://github.com/openMSX/openMSX/releases/download/RELEASE_%{url_ver}/openmsx-catapult-%{version}.tar.gz
Patch1:		openmsx-catapult-skip-binary-strip.patch
BuildRequires:	docbook-utils
BuildRequires:	python3
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(SDL2_ttf)
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
# for catapult
BuildRequires:	libxml2-devel
BuildRequires:	wxgtk-devel >= 3.0.4
Requires:	cbios-openmsx

%description
The open source MSX emulator that tries to achieve
near-perfect emulation by using a novel emulation model.

%files
%doc %{_docdir}/%{name}/
%license doc/GPL.txt
%{_bindir}/openmsx
%{_datadir}/openmsx/
%{_mandir}/man1/openmsx.1*
%dir %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/settings.xml

%package        catapult
Summary:        Graphical interface for openMSX
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    catapult
openMSX Catapult is a graphical user interface for openMSX.
Although the program should be self explanatory, we included a set of HTML
manuals, that tell how to use Catapult with openMSX. To understand what all
options mean and to get a better feeling of what openMSX is, we also recommend
to read the documentation of openMSX.

%files catapult
%doc %{_docdir}/%{name}-catapult
%license doc/GPL.txt
%{_bindir}/%{name}-catapult
%{_datadir}/%{name}-catapult
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

#--------------------------------------------------------------------

%prep
%setup -q -a1
%autopatch -p1

# Make the custom flavour module, so we can use RPM OPT FLAGS here
cat > build/flavour-rpm.mk << EOF
# Opt flags.
CXXFLAGS+=%{build_cxxflags} -DNDEBUG
LINK_FLAGS+=%{build_ldflags}

# Dont strip exe, let rpm do it and save debug info
OPENMSX_STRIP:=false
CATAPULT_STRIP:=false
EOF

# Use same module with catapult
cp build/flavour-rpm.mk %{name}-catapult-%{version}/build

# Build config
cat > build/custom.mk << EOF
PYTHON:=python3
INSTALL_BASE:=%{_prefix}
VERSION_EXEC:=false
SYMLINK_FOR_BINARY:=false
INSTALL_CONTRIB:=false
INSTALL_SHARE_DIR=%{_datadir}/%{name}
INSTALL_DOC_DIR=%{_docdir}/%{name}
EOF

# Build config - catapult
cat > %{name}-catapult-%{version}/build/custom.mk << EOF
PYTHON:=python3
# If we set this to %%{_prefix} catapult cannot find its resources
INSTALL_BASE:=%{_datadir}/%{name}-catapult
SYMLINK_FOR_BINARY:=false
INSTALL_BINARY_DIR=%{_bindir}
INSTALL_SHARE_DIR=%{_datadir}/%{name}-catapult
INSTALL_DOC_DIR=%{_docdir}/%{name}-catapult
CATAPULT_OPENMSX_BINARY:=%{_bindir}/%{name}
CATAPULT_OPENMSX_SHARE:=%{_datadir}/%{name}
CATAPULT_NO_DESKTOP_HOOKS:=false
EOF

%build
%make_build OPENMSX_FLAVOUR=rpm V=1
%make_build CATAPULT_FLAVOUR=rpm V=1 -C %{name}-catapult-%{version}

# Build the man page
docbook2man doc/openmsx.sgml -o ./

%install
%make_install OPENMSX_FLAVOUR=rpm V=1
%make_install CATAPULT_FLAVOUR=rpm V=1 -C %{name}-catapult-%{version}

rm -rf $RPM_BUILD_ROOT%{_docdir}/%{name}{,-catapult}/GPL.txt

mv $RPM_BUILD_ROOT%{_bindir}/catapult $RPM_BUILD_ROOT%{_bindir}/%{name}-catapult

mv $RPM_BUILD_ROOT%{_datadir}/%{name}/machines/*.txt \
   $RPM_BUILD_ROOT%{_docdir}/%{name}

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
mv $RPM_BUILD_ROOT%{_datadir}/%{name}/settings.xml \
   $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
ln -s --target-directory=$RPM_BUILD_ROOT%{_datadir}/%{name} \
   ../../../etc/openmsx/settings.xml

mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
install -pm 0644 OPENMSX.1 $RPM_BUILD_ROOT%{_mandir}/man1/openmsx.1

# Install icon set
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/{16x16,32x32,48x48,64x64,128x128}/apps
for i in 16 32 48 64 128; do
install -pm 0644 share/icons/openMSX-logo-"$i".png \
    $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/"$i"x"$i"/apps/%{name}.png
done

# Install desktop file
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=openMSX Catapult
GenericName=MSX Emulator
Comment=Graphical interface for openMSX
Exec=%{name}-catapult
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;Emulator;
Keywords=emulator;msx;openmsx;
EOF


%changelog
* Fri Jul 15 2022 wally <wally> 18.0-2.mga9
+ Revision: 1868995
- rebuild for wxgtk 3.2.0

* Sat Jun 25 2022 wally <wally> 18.0-1.mga9
+ Revision: 1866190
- new version 18.0

* Sun Jun 12 2022 wally <wally> 17.0-6.mga9
+ Revision: 1864103
- rebuild for wxgtk 3.1.7

* Fri Apr 15 2022 wally <wally> 17.0-5.mga9
+ Revision: 1849984
- rebuild for wxgtk 3.1.6

* Mon Apr 04 2022 umeabot <umeabot> 17.0-4.mga9
+ Revision: 1844061
- Mageia 9 Mass Rebuild

* Sat Jan 15 2022 wally <wally> 17.0-3.mga9
+ Revision: 1768511
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Sat Jan 01 2022 wally <wally> 17.0-2.mga9
+ Revision: 1765700
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Fri Jun 25 2021 wally <wally> 17.0-1.mga9
+ Revision: 1732189
- new version 17.0

* Fri Jan 01 2021 wally <wally> 0.15.0-9.mga8
+ Revision: 1667722
- rebuild for wxgtk pre 3.1.5 snapshot

* Wed Dec 02 2020 luigiwalser <luigiwalser> 0.15.0-8.mga8
+ Revision: 1651364
- rebuild for glew

* Sun Aug 16 2020 wally <wally> 0.15.0-7.mga8
+ Revision: 1614363
- rebuild for new wxgtk 3.1.4

* Wed Mar 04 2020 daviddavid <daviddavid> 0.15.0-6.mga8
+ Revision: 1553585
- port to python3

* Tue Feb 18 2020 umeabot <umeabot> 0.15.0-5.mga8
+ Revision: 1538027
- Mageia 8 Mass Rebuild

* Tue Nov 12 2019 wally <wally> 0.15.0-4.mga8
+ Revision: 1459485
- rebuild for wxgtk 3.1.3

* Mon Jul 08 2019 wally <wally> 0.15.0-3.mga8
+ Revision: 1419531
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jun 30 2019 wally <wally> 0.15.0-2.mga8
+ Revision: 1416382
- rebuild with gtk3 enabled wxgtk 3.1.2
- add patch to fix build

* Sat Mar 09 2019 wally <wally> 0.15.0-1.mga7
+ Revision: 1373151
- new version 0.15.0 (based on .spec from Fedora)
+ dmorgan <dmorgan>
- imported package openmsx

